Rietveld Code Review Tool
Help | Bug tracker | Discussion group | Source code

Unified Diff: adblock-android-tests/src/org/adblockplus/libadblockplus/tests/BaseUpdaterTest.java

Issue 29908555: Issue 7035 - Update libadblockplus dependency (Closed) Base URL: git@github.com:adblockplus/libadblockplus-android.git@d150f08d5d72de8938c7ebbdccd9b0c4e06b4070
Patch Set: Issue 7035 - Update libadblockplus dependency Created Oct. 15, 2018, 9:53 a.m.
Use n/p to move between diff chunks; N/P to move between comments.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: adblock-android-tests/src/org/adblockplus/libadblockplus/tests/BaseUpdaterTest.java
diff --git a/adblock-android-tests/src/org/adblockplus/libadblockplus/tests/BaseFilterEngineTest.java b/adblock-android-tests/src/org/adblockplus/libadblockplus/tests/BaseUpdaterTest.java
similarity index 54%
copy from adblock-android-tests/src/org/adblockplus/libadblockplus/tests/BaseFilterEngineTest.java
copy to adblock-android-tests/src/org/adblockplus/libadblockplus/tests/BaseUpdaterTest.java
index 2741bb8e70b172460c52829e9609683b7e965a99..6096d8f0cd86250a6393bd6368c188adc5c95ce4 100644
--- a/adblock-android-tests/src/org/adblockplus/libadblockplus/tests/BaseFilterEngineTest.java
+++ b/adblock-android-tests/src/org/adblockplus/libadblockplus/tests/BaseUpdaterTest.java
@@ -17,40 +17,40 @@
package org.adblockplus.libadblockplus.tests;
-import org.adblockplus.libadblockplus.FilterEngine;
+import org.adblockplus.libadblockplus.Updater;
import org.adblockplus.libadblockplus.LazyWebRequest;
import org.adblockplus.libadblockplus.WebRequest;
-public abstract class BaseFilterEngineTest extends BasePlatformTest
+public abstract class BaseUpdaterTest extends BasePlatformTest
{
- protected FilterEngine filterEngine;
+ protected Updater updater;
- @Override
- protected void setUp() throws Exception
- {
- super.setUp();
- filterEngine = platform.getFilterEngine();
- }
+ @Override
+ protected void setUp() throws Exception
+ {
+ super.setUp();
+ updater = platform.getUpdater();
+ }
- @Override
- protected void tearDown() throws Exception
- {
- disposeFilterEngine();
- super.tearDown();
- }
+ @Override
+ protected void tearDown() throws Exception
+ {
+ disposeUpdater();
+ super.tearDown();
+ }
- protected void disposeFilterEngine() throws InterruptedException
- {
- if (filterEngine != null)
+ protected void disposeUpdater() throws InterruptedException
{
- Thread.sleep(200); // let FS finish its operations
- filterEngine = null;
+ if (updater != null)
+ {
+ Thread.sleep(200); // let Updater finish its operations
+ updater = null;
+ }
}
- }
- @Override
- protected WebRequest createWebRequest()
- {
- return new LazyWebRequest();
- }
+ @Override
+ protected WebRequest createWebRequest()
+ {
+ return new LazyWebRequest();
+ }
}

Powered by Google App Engine
This is Rietveld